/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2023  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

 #include "../lib/mesh/tri2d_mesh.h"

 using namespace gctl;
 
 int main(int argc, char const *argv[]) try
 {
     mesh_io mshio;
     mshio.read_gmsh_v2_ascii("tmp/tri2d");
     mshio.info();
 
     array<vertex2dc> nodes;
     array<triangle2d> tris;
 
     mshio.select_elements(_3NodeTriangle);
     mshio.export_selected_to(tris, nodes);
     _1d_array data = mshio.get_selected_data("Model slowness (s/km)", ElemData);

     triangle2d_mesh tri2dmesh;
     tri2dmesh.init("Test", "This is a test.", nodes, tris);
     tri2dmesh.add_data(ElemData, "Test Data", data);
     tri2dmesh.show_info();
     tri2dmesh.save_gmsh_withdata("tri2d_out", OverWrite);
     return 0;
 }
 catch(std::exception &e)
 {
     GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
 }